import { Body, Controller, Delete, Get, Param, Post, Put } from '@nestjs/common';
import { AlbumService } from './album.service';
import { Album } from './album.entity';
import { CreateAlbumDto } from './dto/create-album.dto';
import { UpdateAlbumDto } from './dto/update-album.dto';

@Controller('album')
export class AlbumController {

  constructor(private readonly albumService: AlbumService) {}

  @Get()
  findAll(): Promise<Album[]> {
    return this.albumService.findAll();
  }

  @Get(':id')
  findOneById(@Param('id') id: number): Promise<Album | null> {
    return this.albumService.findOneById(id);
  }

  @Post()
  async create(@Body() createAlbumDto: CreateAlbumDto): Promise<number> {
    return this.albumService.create(createAlbumDto);
  }

  @Put()
  async update(@Body() updateAlbumDto: UpdateAlbumDto): Promise<string> {
    return this.albumService.update(updateAlbumDto);
  }

  @Delete(':id')
  async remove(@Param('id') id: number): Promise<void> {
    return this.albumService.remove(id);
  }
}
